\name{blm}
\alias{blm}


\title{Fit a binomial linear regression model}

\description{

A direct probability model for regression with a binary outcome from observational data. 

}

\usage{
blm(formula, data, na.action = na.omit, weights = NULL, 
    strata = NULL, par.init = NULL, ...)
}

\arguments{
  \item{formula}{formula for linear model for binary outcome, \code{event~x1+x2+...}}
  \item{data}{data.frame containing the variables of \code{formula}}
\item{na.action}{function specifying how missing data should be handled, \link{na.action}}
    \item{weights}{Vector of weights equal to the number of observations. For population-based case-control study, weights are the inverse sampling fractions for controls.}
\item{strata}{vector indicating the stratification for weighted regression with stratified observational data}
\item{par.init}{vector (optional) of initial parameters}
\item{...}{Additional arguments passed to \code{constrOptim}}
}

\value{
Returns an object of class \code{blm}.
}

\details{
The \code{blm} model coefficients are the solutions to the maximum of a pseudo log-likelihood using a constrained optimization algorithm with an adaptive barrier method, \code{constrOptim} (Lange, 2010). Variance estimates are based on Taylor linearization (Shah, 2002).

}

\author{S. Kovalchik \email{s.a.kovalchik@gmail.com}}

\seealso{\link{constrOptim}}

\references{
Lange, K. (2010) \emph{Numerical Analysis for Statisticians}, Springer.


Shah, BV. (2002) Calculus of Taylor deviations. Joint Statistical Meetings.
}

\examples{

data(ccdata)

fit <- blm(y~female+packyear, weights = ccdata$w,strata=ccdata$strata,
				data=ccdata)

summary(fit)

}
